=========
pygeobase
=========

This is the documentation of **pygeobase**.


The pygeobase package implements base class definitions for the I/O interface
used in pytesmo_, pynetCF_, and other packages.

Please see the :ref:`modindex` for more details.

.. _pytesmo: https://github.com/TUW-GEO/pytesmo
.. _pynetCF: https://github.com/TUW-GEO/pynetCF

Contents
========

.. toctree::
   :maxdepth: 2

   License <license>
   Authors <authors>
   Module Reference <api/modules>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
